@@ -76,5 +76,5 @@ _ENCODINGS = {
     51949: "euc_kr",
     52936: "hz",
     65000: "utf_7",
-    65001: "utf_8",
+    65001: "utf_8_sig",
 }
