@@ -14,7 +14,7 @@ class TextFileText(TextBase):
         self._filename = filename
 
     def _get_segments(self, include_text: bool) -> Generator[TextSegment, None, None]:
-        with open(self._filename, "r", encoding="utf-8") as file:
+        with open(self._filename, "r", encoding="utf-8-sig") as file:
             section_num = 1
             segment_num = 1
             for line in file:
